Stan Math Library: stan/math/fwd/scal/fun Directory Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

fun Directory Reference

## Files
file | abs.hpp [code]
file | acos.hpp [code]
file | acosh.hpp [code]
file | asin.hpp [code]
file | asinh.hpp [code]
file | atan.hpp [code]
file | atan2.hpp [code]
file | atanh.hpp [code]
file | bessel_first_kind.hpp [code]
file | bessel_second_kind.hpp [code]
file | binary_log_loss.hpp [code]
file | binomial_coefficient_log.hpp [code]
file | cbrt.hpp [code]
file | ceil.hpp [code]
file | cos.hpp [code]
file | cosh.hpp [code]
file | digamma.hpp [code]
file | erf.hpp [code]
file | erfc.hpp [code]
file | exp.hpp [code]
file | exp2.hpp [code]
file | expm1.hpp [code]
file | fabs.hpp [code]
file | falling_factorial.hpp [code]
file | fdim.hpp [code]
file | floor.hpp [code]
file | fma.hpp [code]
file | fmax.hpp [code]
file | fmin.hpp [code]
file | fmod.hpp [code]
file | gamma_p.hpp [code]
file | gamma_q.hpp [code]
file | grad_inc_beta.hpp [code]
file | hypot.hpp [code]
file | inc_beta.hpp [code]
file | inv.hpp [code]
file | inv_cloglog.hpp [code]
file | inv_logit.hpp [code]
file | inv_Phi.hpp [code]
file | inv_sqrt.hpp [code]
file | inv_square.hpp [code]
file | is_inf.hpp [code]
file | is_nan.hpp [code]
file | lbeta.hpp [code]
file | lgamma.hpp [code]
file | lmgamma.hpp [code]
file | log.hpp [code]
file | log10.hpp [code]
file | log1m.hpp [code]
file | log1m_exp.hpp [code]
file | log1m_inv_logit.hpp [code]
file | log1p.hpp [code]
file | log1p_exp.hpp [code]
file | log2.hpp [code]
file | log_diff_exp.hpp [code]
file | log_falling_factorial.hpp [code]
file | log_inv_logit.hpp [code]
file | log_mix.hpp [code]
file | log_rising_factorial.hpp [code]
file | log_sum_exp.hpp [code]
file | logit.hpp [code]
file | modified_bessel_first_kind.hpp [code]
file | modified_bessel_second_kind.hpp [code]
file | multiply_log.hpp [code]
file | owens_t.hpp [code]
file | Phi.hpp [code]
file | pow.hpp [code]
file | primitive_value.hpp [code]
file | rising_factorial.hpp [code]
file | round.hpp [code]
file | sin.hpp [code]
file | sinh.hpp [code]
file | sqrt.hpp [code]
file | square.hpp [code]
file | tan.hpp [code]
file | tanh.hpp [code]
file | tgamma.hpp [code]
file | to_fvar.hpp [code]
file | trunc.hpp [code]
file | value_of.hpp [code]
file | value_of_rec.hpp [code]

[ Stan Home Page ] © 2011–2016, Stan Development Team.